# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/scheduler_v1beta1/proto/cloudscheduler.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.scheduler_v1beta1.proto import (
    job_pb2 as google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/scheduler_v1beta1/proto/cloudscheduler.proto",
    package="google.cloud.scheduler.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        '\n"com.google.cloud.scheduler.v1beta1B\016SchedulerProtoP\001ZGgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1beta1;scheduler\242\002\tSCHEDULER'
    ),
    serialized_pb=_b(
        '\n9google/cloud/scheduler_v1beta1/proto/cloudscheduler.proto\x12\x1egoogle.cloud.scheduler.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/scheduler_v1beta1/proto/job.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"H\n\x0fListJobsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"^\n\x10ListJobsResponse\x12\x31\n\x04jobs\x18\x01 \x03(\x0b\x32#.google.cloud.scheduler.v1beta1.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\x1d\n\rGetJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"T\n\x10\x43reateJobRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x30\n\x03job\x18\x02 \x01(\x0b\x32#.google.cloud.scheduler.v1beta1.Job"u\n\x10UpdateJobRequest\x12\x30\n\x03job\x18\x01 \x01(\x0b\x32#.google.cloud.scheduler.v1beta1.Job\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask" \n\x10\x44\x65leteJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x1f\n\x0fPauseJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t" \n\x10ResumeJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x1d\n\rRunJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t2\x88\n\n\x0e\x43loudScheduler\x12\xa4\x01\n\x08ListJobs\x12/.google.cloud.scheduler.v1beta1.ListJobsRequest\x1a\x30.google.cloud.scheduler.v1beta1.ListJobsResponse"5\x82\xd3\xe4\x93\x02/\x12-/v1beta1/{parent=projects/*/locations/*}/jobs\x12\x93\x01\n\x06GetJob\x12-.google.cloud.scheduler.v1beta1.GetJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job"5\x82\xd3\xe4\x93\x02/\x12-/v1beta1/{name=projects/*/locations/*/jobs/*}\x12\x9e\x01\n\tCreateJob\x12\x30.google.cloud.scheduler.v1beta1.CreateJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job":\x82\xd3\xe4\x93\x02\x34"-/v1beta1/{parent=projects/*/locations/*}/jobs:\x03job\x12\xa2\x01\n\tUpdateJob\x12\x30.google.cloud.scheduler.v1beta1.UpdateJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job">\x82\xd3\xe4\x93\x02\x38\x32\x31/v1beta1/{job.name=projects/*/locations/*/jobs/*}:\x03job\x12\x8c\x01\n\tDeleteJob\x12\x30.google.cloud.scheduler.v1beta1.DeleteJobRequest\x1a\x16.google.protobuf.Empty"5\x82\xd3\xe4\x93\x02/*-/v1beta1/{name=projects/*/locations/*/jobs/*}\x12\xa0\x01\n\x08PauseJob\x12/.google.cloud.scheduler.v1beta1.PauseJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job">\x82\xd3\xe4\x93\x02\x38"3/v1beta1/{name=projects/*/locations/*/jobs/*}:pause:\x01*\x12\xa3\x01\n\tResumeJob\x12\x30.google.cloud.scheduler.v1beta1.ResumeJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job"?\x82\xd3\xe4\x93\x02\x39"4/v1beta1/{name=projects/*/locations/*/jobs/*}:resume:\x01*\x12\x9a\x01\n\x06RunJob\x12-.google.cloud.scheduler.v1beta1.RunJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job"<\x82\xd3\xe4\x93\x02\x36"1/v1beta1/{name=projects/*/locations/*/jobs/*}:run:\x01*B\x8b\x01\n"com.google.cloud.scheduler.v1beta1B\x0eSchedulerProtoP\x01ZGgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1beta1;scheduler\xa2\x02\tSCHEDULERb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_LISTJOBSREQUEST = _descriptor.Descriptor(
    name="ListJobsRequest",
    full_name="google.cloud.scheduler.v1beta1.ListJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.scheduler.v1beta1.ListJobsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.scheduler.v1beta1.ListJobsRequest.page_size",
            index=1,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.scheduler.v1beta1.ListJobsRequest.page_token",
            index=2,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=261,
    serialized_end=333,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
    name="ListJobsResponse",
    full_name="google.cloud.scheduler.v1beta1.ListJobsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="jobs",
            full_name="google.cloud.scheduler.v1beta1.ListJobsResponse.jobs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.scheduler.v1beta1.ListJobsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=335,
    serialized_end=429,
)


_GETJOBREQUEST = _descriptor.Descriptor(
    name="GetJobRequest",
    full_name="google.cloud.scheduler.v1beta1.GetJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.scheduler.v1beta1.GetJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=431,
    serialized_end=460,
)


_CREATEJOBREQUEST = _descriptor.Descriptor(
    name="CreateJobRequest",
    full_name="google.cloud.scheduler.v1beta1.CreateJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.scheduler.v1beta1.CreateJobRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.scheduler.v1beta1.CreateJobRequest.job",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=462,
    serialized_end=546,
)


_UPDATEJOBREQUEST = _descriptor.Descriptor(
    name="UpdateJobRequest",
    full_name="google.cloud.scheduler.v1beta1.UpdateJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.scheduler.v1beta1.UpdateJobRequest.job",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.scheduler.v1beta1.UpdateJobRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=548,
    serialized_end=665,
)


_DELETEJOBREQUEST = _descriptor.Descriptor(
    name="DeleteJobRequest",
    full_name="google.cloud.scheduler.v1beta1.DeleteJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.scheduler.v1beta1.DeleteJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=667,
    serialized_end=699,
)


_PAUSEJOBREQUEST = _descriptor.Descriptor(
    name="PauseJobRequest",
    full_name="google.cloud.scheduler.v1beta1.PauseJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.scheduler.v1beta1.PauseJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=701,
    serialized_end=732,
)


_RESUMEJOBREQUEST = _descriptor.Descriptor(
    name="ResumeJobRequest",
    full_name="google.cloud.scheduler.v1beta1.ResumeJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.scheduler.v1beta1.ResumeJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=734,
    serialized_end=766,
)


_RUNJOBREQUEST = _descriptor.Descriptor(
    name="RunJobRequest",
    full_name="google.cloud.scheduler.v1beta1.RunJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.scheduler.v1beta1.RunJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=768,
    serialized_end=797,
)

_LISTJOBSRESPONSE.fields_by_name[
    "jobs"
].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB
_CREATEJOBREQUEST.fields_by_name[
    "job"
].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name[
    "job"
].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name["ListJobsRequest"] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name["ListJobsResponse"] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name["GetJobRequest"] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name["CreateJobRequest"] = _CREATEJOBREQUEST
DESCRIPTOR.message_types_by_name["UpdateJobRequest"] = _UPDATEJOBREQUEST
DESCRIPTOR.message_types_by_name["DeleteJobRequest"] = _DELETEJOBREQUEST
DESCRIPTOR.message_types_by_name["PauseJobRequest"] = _PAUSEJOBREQUEST
DESCRIPTOR.message_types_by_name["ResumeJobRequest"] = _RESUMEJOBREQUEST
DESCRIPTOR.message_types_by_name["RunJobRequest"] = _RUNJOBREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListJobsRequest = _reflection.GeneratedProtocolMessageType(
    "ListJobsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTJOBSREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for listing jobs using
  [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
  
  
  Attributes:
      parent:
          Required.  The location name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID``.
      page_size:
          Requested page size.  The maximum page size is 500. If
          unspecified, the page size will be the maximum. Fewer jobs
          than requested might be returned, even if more jobs exist; use
          next\_page\_token to determine if more jobs exist.
      page_token:
          A token identifying a page of results the server will return.
          To request the first page results, page\_token must be empty.
          To request the next page of results, page\_token must be the
          value of [next\_page\_token][google.cloud.scheduler.v1beta1.Li
          stJobsResponse.next\_page\_token] returned from the previous
          call to [ListJobs][google.cloud.scheduler.v1beta1.CloudSchedul
          er.ListJobs]. It is an error to switch the value of [filter][g
          oogle.cloud.scheduler.v1beta1.ListJobsRequest.filter] or [orde
          r\_by][google.cloud.scheduler.v1beta1.ListJobsRequest.order\_b
          y] while iterating through pages.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.ListJobsRequest)
    ),
)
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType(
    "ListJobsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTJOBSRESPONSE,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Response message for listing jobs using
  [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
  
  
  Attributes:
      jobs:
          The list of jobs.
      next_page_token:
          A token to retrieve next page of results. Pass this value in
          the [page\_token][google.cloud.scheduler.v1beta1.ListJobsReque
          st.page\_token] field in the subsequent call to [ListJobs][goo
          gle.cloud.scheduler.v1beta1.CloudScheduler.ListJobs] to
          retrieve the next page of results. If this is empty it
          indicates that there are no more results through which to
          paginate.  The page token is valid for only 2 hours.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.ListJobsResponse)
    ),
)
_sym_db.RegisterMessage(ListJobsResponse)

GetJobRequest = _reflection.GeneratedProtocolMessageType(
    "GetJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for
  [GetJob][google.cloud.scheduler.v1beta1.CloudScheduler.GetJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.GetJobRequest)
    ),
)
_sym_db.RegisterMessage(GetJobRequest)

CreateJobRequest = _reflection.GeneratedProtocolMessageType(
    "CreateJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for
  [CreateJob][google.cloud.scheduler.v1beta1.CloudScheduler.CreateJob].
  
  
  Attributes:
      parent:
          Required.  The location name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID``.
      job:
          Required.  The job to add. The user can optionally specify a
          name for the job in
          [name][google.cloud.scheduler.v1beta1.Job.name].
          [name][google.cloud.scheduler.v1beta1.Job.name] cannot be the
          same as an existing job. If a name is not specified then the
          system will generate a random unique name that will be
          returned ([name][google.cloud.scheduler.v1beta1.Job.name]) in
          the response.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.CreateJobRequest)
    ),
)
_sym_db.RegisterMessage(CreateJobRequest)

UpdateJobRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for
  [UpdateJob][google.cloud.scheduler.v1beta1.CloudScheduler.UpdateJob].
  
  
  Attributes:
      job:
          Required.  The new job properties.
          [name][google.cloud.scheduler.v1beta1.Job.name] must be
          specified.  Output only fields cannot be modified using
          UpdateJob. Any value specified for an output only field will
          be ignored.
      update_mask:
          A mask used to specify which fields of the job are being
          updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.UpdateJobRequest)
    ),
)
_sym_db.RegisterMessage(UpdateJobRequest)

DeleteJobRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for deleting a job using
  [DeleteJob][google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.DeleteJobRequest)
    ),
)
_sym_db.RegisterMessage(DeleteJobRequest)

PauseJobRequest = _reflection.GeneratedProtocolMessageType(
    "PauseJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_PAUSEJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for
  [PauseJob][google.cloud.scheduler.v1beta1.CloudScheduler.PauseJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.PauseJobRequest)
    ),
)
_sym_db.RegisterMessage(PauseJobRequest)

ResumeJobRequest = _reflection.GeneratedProtocolMessageType(
    "ResumeJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RESUMEJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for
  [ResumeJob][google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.ResumeJobRequest)
    ),
)
_sym_db.RegisterMessage(ResumeJobRequest)

RunJobRequest = _reflection.GeneratedProtocolMessageType(
    "RunJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RUNJOBREQUEST,
        __module__="google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2",
        __doc__="""Request message for forcing a job to run now using
  [RunJob][google.cloud.scheduler.v1beta1.CloudScheduler.RunJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.RunJobRequest)
    ),
)
_sym_db.RegisterMessage(RunJobRequest)


DESCRIPTOR._options = None

_CLOUDSCHEDULER = _descriptor.ServiceDescriptor(
    name="CloudScheduler",
    full_name="google.cloud.scheduler.v1beta1.CloudScheduler",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=800,
    serialized_end=2088,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListJobs",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs",
            index=0,
            containing_service=None,
            input_type=_LISTJOBSREQUEST,
            output_type=_LISTJOBSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002/\022-/v1beta1/{parent=projects/*/locations/*}/jobs"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.GetJob",
            index=1,
            containing_service=None,
            input_type=_GETJOBREQUEST,
            output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                "\202\323\344\223\002/\022-/v1beta1/{name=projects/*/locations/*/jobs/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.CreateJob",
            index=2,
            containing_service=None,
            input_type=_CREATEJOBREQUEST,
            output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                '\202\323\344\223\0024"-/v1beta1/{parent=projects/*/locations/*}/jobs:\003job'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.UpdateJob",
            index=3,
            containing_service=None,
            input_type=_UPDATEJOBREQUEST,
            output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                "\202\323\344\223\002821/v1beta1/{job.name=projects/*/locations/*/jobs/*}:\003job"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob",
            index=4,
            containing_service=None,
            input_type=_DELETEJOBREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002/*-/v1beta1/{name=projects/*/locations/*/jobs/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="PauseJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.PauseJob",
            index=5,
            containing_service=None,
            input_type=_PAUSEJOBREQUEST,
            output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                '\202\323\344\223\0028"3/v1beta1/{name=projects/*/locations/*/jobs/*}:pause:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ResumeJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob",
            index=6,
            containing_service=None,
            input_type=_RESUMEJOBREQUEST,
            output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                '\202\323\344\223\0029"4/v1beta1/{name=projects/*/locations/*/jobs/*}:resume:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="RunJob",
            full_name="google.cloud.scheduler.v1beta1.CloudScheduler.RunJob",
            index=7,
            containing_service=None,
            input_type=_RUNJOBREQUEST,
            output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                '\202\323\344\223\0026"1/v1beta1/{name=projects/*/locations/*/jobs/*}:run:\001*'
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_CLOUDSCHEDULER)

DESCRIPTOR.services_by_name["CloudScheduler"] = _CLOUDSCHEDULER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/scheduler_v1/proto/target.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/scheduler_v1/proto/target.proto",
    package="google.cloud.scheduler.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\035com.google.cloud.scheduler.v1B\013TargetProtoP\001ZBgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1;scheduler"
    ),
    serialized_pb=_b(
        '\n,google/cloud/scheduler_v1/proto/target.proto\x12\x19google.cloud.scheduler.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto"\xd8\x01\n\nHttpTarget\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12:\n\x0bhttp_method\x18\x02 \x01(\x0e\x32%.google.cloud.scheduler.v1.HttpMethod\x12\x43\n\x07headers\x18\x03 \x03(\x0b\x32\x32.google.cloud.scheduler.v1.HttpTarget.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x04 \x01(\x0c\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xbc\x02\n\x13\x41ppEngineHttpTarget\x12:\n\x0bhttp_method\x18\x01 \x01(\x0e\x32%.google.cloud.scheduler.v1.HttpMethod\x12G\n\x12\x61pp_engine_routing\x18\x02 \x01(\x0b\x32+.google.cloud.scheduler.v1.AppEngineRouting\x12\x14\n\x0crelative_uri\x18\x03 \x01(\t\x12L\n\x07headers\x18\x04 \x03(\x0b\x32;.google.cloud.scheduler.v1.AppEngineHttpTarget.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x05 \x01(\x0c\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xb0\x01\n\x0cPubsubTarget\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12K\n\nattributes\x18\x04 \x03(\x0b\x32\x37.google.cloud.scheduler.v1.PubsubTarget.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"T\n\x10\x41ppEngineRouting\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0c\n\x04host\x18\x04 \x01(\t*s\n\nHttpMethod\x12\x1b\n\x17HTTP_METHOD_UNSPECIFIED\x10\x00\x12\x08\n\x04POST\x10\x01\x12\x07\n\x03GET\x10\x02\x12\x08\n\x04HEAD\x10\x03\x12\x07\n\x03PUT\x10\x04\x12\n\n\x06\x44\x45LETE\x10\x05\x12\t\n\x05PATCH\x10\x06\x12\x0b\n\x07OPTIONS\x10\x07\x42r\n\x1d\x63om.google.cloud.scheduler.v1B\x0bTargetProtoP\x01ZBgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1;schedulerb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ],
)

_HTTPMETHOD = _descriptor.EnumDescriptor(
    name="HttpMethod",
    full_name="google.cloud.scheduler.v1.HttpMethod",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="HTTP_METHOD_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="POST", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="GET", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="HEAD", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PUT", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DELETE", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PATCH", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OPTIONS", index=7, number=7, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=935,
    serialized_end=1050,
)
_sym_db.RegisterEnumDescriptor(_HTTPMETHOD)

HttpMethod = enum_type_wrapper.EnumTypeWrapper(_HTTPMETHOD)
HTTP_METHOD_UNSPECIFIED = 0
POST = 1
GET = 2
HEAD = 3
PUT = 4
DELETE = 5
PATCH = 6
OPTIONS = 7


_HTTPTARGET_HEADERSENTRY = _descriptor.Descriptor(
    name="HeadersEntry",
    full_name="google.cloud.scheduler.v1.HttpTarget.HeadersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.scheduler.v1.HttpTarget.HeadersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.scheduler.v1.HttpTarget.HeadersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=303,
    serialized_end=349,
)

_HTTPTARGET = _descriptor.Descriptor(
    name="HttpTarget",
    full_name="google.cloud.scheduler.v1.HttpTarget",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.scheduler.v1.HttpTarget.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="http_method",
            full_name="google.cloud.scheduler.v1.HttpTarget.http_method",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="headers",
            full_name="google.cloud.scheduler.v1.HttpTarget.headers",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="body",
            full_name="google.cloud.scheduler.v1.HttpTarget.body",
            index=3,
            number=4,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_HTTPTARGET_HEADERSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=133,
    serialized_end=349,
)


_APPENGINEHTTPTARGET_HEADERSENTRY = _descriptor.Descriptor(
    name="HeadersEntry",
    full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.HeadersEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.HeadersEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.HeadersEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=303,
    serialized_end=349,
)

_APPENGINEHTTPTARGET = _descriptor.Descriptor(
    name="AppEngineHttpTarget",
    full_name="google.cloud.scheduler.v1.AppEngineHttpTarget",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="http_method",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.http_method",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="app_engine_routing",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.app_engine_routing",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="relative_uri",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.relative_uri",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="headers",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.headers",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="body",
            full_name="google.cloud.scheduler.v1.AppEngineHttpTarget.body",
            index=4,
            number=5,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_APPENGINEHTTPTARGET_HEADERSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=352,
    serialized_end=668,
)


_PUBSUBTARGET_ATTRIBUTESENTRY = _descriptor.Descriptor(
    name="AttributesEntry",
    full_name="google.cloud.scheduler.v1.PubsubTarget.AttributesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.scheduler.v1.PubsubTarget.AttributesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.scheduler.v1.PubsubTarget.AttributesEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=798,
    serialized_end=847,
)

_PUBSUBTARGET = _descriptor.Descriptor(
    name="PubsubTarget",
    full_name="google.cloud.scheduler.v1.PubsubTarget",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic_name",
            full_name="google.cloud.scheduler.v1.PubsubTarget.topic_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="google.cloud.scheduler.v1.PubsubTarget.data",
            index=1,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="attributes",
            full_name="google.cloud.scheduler.v1.PubsubTarget.attributes",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PUBSUBTARGET_ATTRIBUTESENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=671,
    serialized_end=847,
)


_APPENGINEROUTING = _descriptor.Descriptor(
    name="AppEngineRouting",
    full_name="google.cloud.scheduler.v1.AppEngineRouting",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="service",
            full_name="google.cloud.scheduler.v1.AppEngineRouting.service",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="google.cloud.scheduler.v1.AppEngineRouting.version",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="instance",
            full_name="google.cloud.scheduler.v1.AppEngineRouting.instance",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="host",
            full_name="google.cloud.scheduler.v1.AppEngineRouting.host",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=849,
    serialized_end=933,
)

_HTTPTARGET_HEADERSENTRY.containing_type = _HTTPTARGET
_HTTPTARGET.fields_by_name["http_method"].enum_type = _HTTPMETHOD
_HTTPTARGET.fields_by_name["headers"].message_type = _HTTPTARGET_HEADERSENTRY
_APPENGINEHTTPTARGET_HEADERSENTRY.containing_type = _APPENGINEHTTPTARGET
_APPENGINEHTTPTARGET.fields_by_name["http_method"].enum_type = _HTTPMETHOD
_APPENGINEHTTPTARGET.fields_by_name[
    "app_engine_routing"
].message_type = _APPENGINEROUTING
_APPENGINEHTTPTARGET.fields_by_name[
    "headers"
].message_type = _APPENGINEHTTPTARGET_HEADERSENTRY
_PUBSUBTARGET_ATTRIBUTESENTRY.containing_type = _PUBSUBTARGET
_PUBSUBTARGET.fields_by_name["attributes"].message_type = _PUBSUBTARGET_ATTRIBUTESENTRY
DESCRIPTOR.message_types_by_name["HttpTarget"] = _HTTPTARGET
DESCRIPTOR.message_types_by_name["AppEngineHttpTarget"] = _APPENGINEHTTPTARGET
DESCRIPTOR.message_types_by_name["PubsubTarget"] = _PUBSUBTARGET
DESCRIPTOR.message_types_by_name["AppEngineRouting"] = _APPENGINEROUTING
DESCRIPTOR.enum_types_by_name["HttpMethod"] = _HTTPMETHOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpTarget = _reflection.GeneratedProtocolMessageType(
    "HttpTarget",
    (_message.Message,),
    dict(
        HeadersEntry=_reflection.GeneratedProtocolMessageType(
            "HeadersEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_HTTPTARGET_HEADERSENTRY,
                __module__="google.cloud.scheduler_v1.proto.target_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.HttpTarget.HeadersEntry)
            ),
        ),
        DESCRIPTOR=_HTTPTARGET,
        __module__="google.cloud.scheduler_v1.proto.target_pb2",
        __doc__="""Http target. The job will be pushed to the job handler by means of an
  HTTP request via an
  [http\_method][google.cloud.scheduler.v1.HttpTarget.http\_method] such
  as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an HTTP
  response code in the range [200 - 299]. A failure to receive a response
  constitutes a failed execution. For a redirected request, the response
  returned by the redirected request is considered.
  
  
  Attributes:
      uri:
          Required.  The full URI path that the request will be sent to.
          This string must begin with either "http://" or "https://".
          Some examples of valid values for
          [uri][google.cloud.scheduler.v1.HttpTarget.uri] are:
          ``http://acme.com`` and ``https://acme.com/sales:8080``. Cloud
          Scheduler will encode some characters for safety and
          compatibility. The maximum allowed URL length is 2083
          characters after encoding.
      http_method:
          Which HTTP method to use for the request.
      headers:
          The user can specify HTTP request headers to send with the
          job's HTTP request. This map contains the header field names
          and values. Repeated headers are not supported, but a header
          value can contain commas. These headers represent a subset of
          the headers that will accompany the job's HTTP request. Some
          HTTP request headers will be ignored or replaced. A partial
          list of headers that will be ignored or replaced is below: -
          Host: This will be computed by Cloud Scheduler and derived
          from [uri][google.cloud.scheduler.v1.HttpTarget.uri]. \*
          ``Content-Length``: This will be computed by Cloud Scheduler.
          \* ``User-Agent``: This will be set to ``"Google-Cloud-
          Scheduler"``. \* ``X-Google-*``: Google internal use only. \*
          ``X-AppEngine-*``: Google internal use only.  The total size
          of headers must be less than 80KB.
      body:
          HTTP request body. A request body is allowed only if the HTTP
          method is POST, PUT, or PATCH. It is an error to set body on a
          job with an incompatible
          [HttpMethod][google.cloud.scheduler.v1.HttpMethod].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.HttpTarget)
    ),
)
_sym_db.RegisterMessage(HttpTarget)
_sym_db.RegisterMessage(HttpTarget.HeadersEntry)

AppEngineHttpTarget = _reflection.GeneratedProtocolMessageType(
    "AppEngineHttpTarget",
    (_message.Message,),
    dict(
        HeadersEntry=_reflection.GeneratedProtocolMessageType(
            "HeadersEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_APPENGINEHTTPTARGET_HEADERSENTRY,
                __module__="google.cloud.scheduler_v1.proto.target_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.AppEngineHttpTarget.HeadersEntry)
            ),
        ),
        DESCRIPTOR=_APPENGINEHTTPTARGET,
        __module__="google.cloud.scheduler_v1.proto.target_pb2",
        __doc__="""App Engine target. The job will be pushed to a job handler by means of
  an HTTP request via an
  [http\_method][google.cloud.scheduler.v1.AppEngineHttpTarget.http\_method]
  such as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an
  HTTP response code in the range [200 - 299]. Error 503 is considered an
  App Engine system error instead of an application error. Requests
  returning error 503 will be retried regardless of retry configuration
  and not counted against retry counts. Any other response code, or a
  failure to receive a response before the deadline, constitutes a failed
  attempt.
  
  
  Attributes:
      http_method:
          The HTTP method to use for the request. PATCH and OPTIONS are
          not permitted.
      app_engine_routing:
          App Engine Routing setting for the job.
      relative_uri:
          The relative URI.  The relative URL must begin with "/" and
          must be a valid HTTP relative URL. It can contain a path,
          query string arguments, and ``#`` fragments. If the relative
          URL is empty, then the root path "/" will be used. No spaces
          are allowed, and the maximum length allowed is 2083
          characters.
      headers:
          HTTP request headers.  This map contains the header field
          names and values. Headers can be set when the job is created.
          Cloud Scheduler sets some headers to default values:  -
          ``User-Agent``: By default, this header is    ``"AppEngine-
          Google; (+http://code.google.com/appengine)"``. This    header
          can be modified, but Cloud Scheduler will append
          ``"AppEngine-Google; (+http://code.google.com/appengine)"`` to
          the    modified ``User-Agent``. -  ``X-CloudScheduler``: This
          header will be set to true.  If the job has an
          [body][google.cloud.scheduler.v1.AppEngineHttpTarget.body],
          Cloud Scheduler sets the following headers:  -  ``Content-
          Type``: By default, the ``Content-Type`` header is set to
          ``"application/octet-stream"``. The default can be overridden
          by    explictly setting ``Content-Type`` to a particular media
          type when    the job is created. For example, ``Content-Type``
          can be set to    ``"application/json"``. -  ``Content-
          Length``: This is computed by Cloud Scheduler. This value
          is output only. It cannot be changed.  The headers below are
          output only. They cannot be set or overridden:  -
          ``X-Google-*``: For Google internal use only. -
          ``X-AppEngine-*``: For Google internal use only.  In addition,
          some App Engine headers, which contain job-specific
          information, are also be sent to the job handler.
      body:
          Body.  HTTP request body. A request body is allowed only if
          the HTTP method is POST or PUT. It will result in invalid
          argument error to set a body on a job with an incompatible
          [HttpMethod][google.cloud.scheduler.v1.HttpMethod].
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.AppEngineHttpTarget)
    ),
)
_sym_db.RegisterMessage(AppEngineHttpTarget)
_sym_db.RegisterMessage(AppEngineHttpTarget.HeadersEntry)

PubsubTarget = _reflection.GeneratedProtocolMessageType(
    "PubsubTarget",
    (_message.Message,),
    dict(
        AttributesEntry=_reflection.GeneratedProtocolMessageType(
            "AttributesEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PUBSUBTARGET_ATTRIBUTESENTRY,
                __module__="google.cloud.scheduler_v1.proto.target_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.PubsubTarget.AttributesEntry)
            ),
        ),
        DESCRIPTOR=_PUBSUBTARGET,
        __module__="google.cloud.scheduler_v1.proto.target_pb2",
        __doc__="""Pub/Sub target. The job will be delivered by publishing a message to the
  given Pub/Sub topic.
  
  
  Attributes:
      topic_name:
          Required.  The name of the Cloud Pub/Sub topic to which
          messages will be published when a job is delivered. The topic
          name must be in the same format as required by PubSub's
          `PublishRequest.name <https://cloud.google.com/pubsub/docs/ref
          erence/rpc/google.pubsub.v1#publishrequest>`__, for example
          ``projects/PROJECT_ID/topics/TOPIC_ID``.  The topic must be in
          the same project as the Cloud Scheduler job.
      data:
          The message payload for PubsubMessage.  Pubsub message must
          contain either non-empty data, or at least one attribute.
      attributes:
          Attributes for PubsubMessage.  Pubsub message must contain
          either non-empty data, or at least one attribute.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.PubsubTarget)
    ),
)
_sym_db.RegisterMessage(PubsubTarget)
_sym_db.RegisterMessage(PubsubTarget.AttributesEntry)

AppEngineRouting = _reflection.GeneratedProtocolMessageType(
    "AppEngineRouting",
    (_message.Message,),
    dict(
        DESCRIPTOR=_APPENGINEROUTING,
        __module__="google.cloud.scheduler_v1.proto.target_pb2",
        __doc__="""App Engine Routing.
  
  For more information about services, versions, and instances see `An
  Overview of App
  Engine <https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine>`__,
  `Microservices Architecture on Google App
  Engine <https://cloud.google.com/appengine/docs/python/microservices-on-app-engine>`__,
  `App Engine Standard request
  routing <https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed>`__,
  and `App Engine Flex request
  routing <https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed>`__.
  
  
  Attributes:
      service:
          App service.  By default, the job is sent to the service which
          is the default service when the job is attempted.
      version:
          App version.  By default, the job is sent to the version which
          is the default version when the job is attempted.
      instance:
          App instance.  By default, the job is sent to an instance
          which is available when the job is attempted.  Requests can
          only be sent to a specific instance if `manual scaling is used
          in App Engine Standard
          <https://cloud.google.com/appengine/docs/python/an-overview-
          of-app-engine?hl=en_US#scaling_types_and_instance_classes>`__.
          App Engine Flex does not support instances. For more
          information, see `App Engine Standard request routing
          <https://cloud.google.com/appengine/docs/standard/python/how-
          requests-are-routed>`__ and `App Engine Flex request routing
          <https://cloud.google.com/appengine/docs/flexible/python/how-
          requests-are-routed>`__.
      host:
          Output only. The host that the job is sent to.  For more
          information about how App Engine requests are routed, see
          `here
          <https://cloud.google.com/appengine/docs/standard/python/how-
          requests-are-routed>`__.  The host is constructed as:  -
          ``host = [application_domain_name]``\     ``| [service] + '.'
          + [application_domain_name]``\     ``| [version] + '.' +
          [application_domain_name]``\     ``| [version_dot_service]+
          '.' + [application_domain_name]``\     ``| [instance] + '.' +
          [application_domain_name]``\     ``| [instance_dot_service] +
          '.' + [application_domain_name]``\     ``|
          [instance_dot_version] + '.' + [application_domain_name]``\
          ``| [instance_dot_version_dot_service] + '.' +
          [application_domain_name]``  -  ``application_domain_name`` =
          The domain name of the app, for example    .appspot.com, which
          is associated with the job's project ID.  -  ``service =``
          [service][google.cloud.scheduler.v1.AppEngineRouting.service]
          -  ``version =``
          [version][google.cloud.scheduler.v1.AppEngineRouting.version]
          -  ``version_dot_service =``
          [version][google.cloud.scheduler.v1.AppEngineRouting.version]
          ``+ '.' +``
          [service][google.cloud.scheduler.v1.AppEngineRouting.service]
          -  ``instance =``    [instance][google.cloud.scheduler.v1.AppE
          ngineRouting.instance]  -  ``instance_dot_service =``    [inst
          ance][google.cloud.scheduler.v1.AppEngineRouting.instance]
          ``+ '.' +``
          [service][google.cloud.scheduler.v1.AppEngineRouting.service]
          -  ``instance_dot_version =``    [instance][google.cloud.sched
          uler.v1.AppEngineRouting.instance]    ``+ '.' +``
          [version][google.cloud.scheduler.v1.AppEngineRouting.version]
          -  ``instance_dot_version_dot_service =``    [instance][google
          .cloud.scheduler.v1.AppEngineRouting.instance]    ``+ '.' +``
          [version][google.cloud.scheduler.v1.AppEngineRouting.version]
          ``+ '.' +``
          [service][google.cloud.scheduler.v1.AppEngineRouting.service]
          If
          [service][google.cloud.scheduler.v1.AppEngineRouting.service]
          is empty, then the job will be sent to the service which is
          the default service when the job is attempted.  If
          [version][google.cloud.scheduler.v1.AppEngineRouting.version]
          is empty, then the job will be sent to the version which is
          the default version when the job is attempted.  If [instance][
          google.cloud.scheduler.v1.AppEngineRouting.instance] is empty,
          then the job will be sent to an instance which is available
          when the job is attempted.  If
          [service][google.cloud.scheduler.v1.AppEngineRouting.service],
          [version][google.cloud.scheduler.v1.AppEngineRouting.version],
          or [instance][google.cloud.scheduler.v1.AppEngineRouting.insta
          nce] is invalid, then the job will be sent to the default
          version of the default service when the job is attempted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.AppEngineRouting)
    ),
)
_sym_db.RegisterMessage(AppEngineRouting)


DESCRIPTOR._options = None
_HTTPTARGET_HEADERSENTRY._options = None
_APPENGINEHTTPTARGET_HEADERSENTRY._options = None
_PUBSUBTARGET_ATTRIBUTESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import google.api_core.grpc_helpers

from google.cloud.scheduler_v1.proto import cloudscheduler_pb2_grpc


class CloudSchedulerGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.scheduler.v1 CloudScheduler API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self,
        channel=None,
        credentials=None,
        address="cloudscheduler.googleapis.com:443",
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(address=address, credentials=credentials)

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            "cloud_scheduler_stub": cloudscheduler_pb2_grpc.CloudSchedulerStub(channel)
        }

    @classmethod
    def create_channel(
        cls, address="cloudscheduler.googleapis.com:443", credentials=None
    ):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def list_jobs(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.list_jobs`.

        Lists jobs.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].ListJobs

    @property
    def get_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.get_job`.

        Gets a job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].GetJob

    @property
    def create_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.create_job`.

        Creates a job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].CreateJob

    @property
    def update_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.update_job`.

        Updates a job.

        If successful, the updated ``Job`` is returned. If the job does not
        exist, ``NOT_FOUND`` is returned.

        If UpdateJob does not successfully return, it is possible for the job to
        be in an ``Job.State.UPDATE_FAILED`` state. A job in this state may not
        be executed. If this happens, retry the UpdateJob request until a
        successful response is received.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].UpdateJob

    @property
    def delete_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.delete_job`.

        Deletes a job.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].DeleteJob

    @property
    def pause_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.pause_job`.

        Pauses a job.

        If a job is paused then the system will stop executing the job until it
        is re-enabled via ``ResumeJob``. The state of the job is stored in
        ``state``; if paused it will be set to ``Job.State.PAUSED``. A job must
        be in ``Job.State.ENABLED`` to be paused.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].PauseJob

    @property
    def resume_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.resume_job`.

        Resume a job.

        This method reenables a job after it has been ``Job.State.PAUSED``. The
        state of a job is stored in ``Job.state``; after calling this method it
        will be set to ``Job.State.ENABLED``. A job must be in
        ``Job.State.PAUSED`` to be resumed.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].ResumeJob

    @property
    def run_job(self):
        """Return the gRPC stub for :meth:`CloudSchedulerClient.run_job`.

        Forces a job to run now.

        When this method is called, Cloud Scheduler will dispatch the job, even
        if the job is already running.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["cloud_scheduler_stub"].RunJob



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.scheduler_v1.proto import (
    cloudscheduler_pb2 as google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2,
)
from google.cloud.scheduler_v1.proto import (
    job_pb2 as google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CloudSchedulerStub(object):
    """The Cloud Scheduler API allows external entities to reliably
  schedule asynchronous jobs.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.ListJobs = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/ListJobs",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.ListJobsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.ListJobsResponse.FromString,
        )
        self.GetJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/GetJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.GetJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.CreateJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/CreateJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.CreateJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.UpdateJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/UpdateJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.UpdateJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.DeleteJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/DeleteJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.DeleteJobRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.PauseJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/PauseJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.PauseJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.ResumeJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/ResumeJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.ResumeJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.RunJob = channel.unary_unary(
            "/google.cloud.scheduler.v1.CloudScheduler/RunJob",
            request_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.RunJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.FromString,
        )


class CloudSchedulerServicer(object):
    """The Cloud Scheduler API allows external entities to reliably
  schedule asynchronous jobs.
  """

    def ListJobs(self, request, context):
        """Lists jobs.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetJob(self, request, context):
        """Gets a job.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateJob(self, request, context):
        """Creates a job.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateJob(self, request, context):
        """Updates a job.

    If successful, the updated [Job][google.cloud.scheduler.v1.Job] is returned. If the job does
    not exist, `NOT_FOUND` is returned.

    If UpdateJob does not successfully return, it is possible for the
    job to be in an [Job.State.UPDATE_FAILED][google.cloud.scheduler.v1.Job.State.UPDATE_FAILED] state. A job in this state may
    not be executed. If this happens, retry the UpdateJob request
    until a successful response is received.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteJob(self, request, context):
        """Deletes a job.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PauseJob(self, request, context):
        """Pauses a job.

    If a job is paused then the system will stop executing the job
    until it is re-enabled via [ResumeJob][google.cloud.scheduler.v1.CloudScheduler.ResumeJob]. The
    state of the job is stored in [state][google.cloud.scheduler.v1.Job.state]; if paused it
    will be set to [Job.State.PAUSED][google.cloud.scheduler.v1.Job.State.PAUSED]. A job must be in [Job.State.ENABLED][google.cloud.scheduler.v1.Job.State.ENABLED]
    to be paused.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ResumeJob(self, request, context):
        """Resume a job.

    This method reenables a job after it has been [Job.State.PAUSED][google.cloud.scheduler.v1.Job.State.PAUSED]. The
    state of a job is stored in [Job.state][google.cloud.scheduler.v1.Job.state]; after calling this method it
    will be set to [Job.State.ENABLED][google.cloud.scheduler.v1.Job.State.ENABLED]. A job must be in
    [Job.State.PAUSED][google.cloud.scheduler.v1.Job.State.PAUSED] to be resumed.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RunJob(self, request, context):
        """Forces a job to run now.

    When this method is called, Cloud Scheduler will dispatch the job, even
    if the job is already running.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CloudSchedulerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListJobs": grpc.unary_unary_rpc_method_handler(
            servicer.ListJobs,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.ListJobsRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.ListJobsResponse.SerializeToString,
        ),
        "GetJob": grpc.unary_unary_rpc_method_handler(
            servicer.GetJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.GetJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "CreateJob": grpc.unary_unary_rpc_method_handler(
            servicer.CreateJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.CreateJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "UpdateJob": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.UpdateJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "DeleteJob": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.DeleteJobRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "PauseJob": grpc.unary_unary_rpc_method_handler(
            servicer.PauseJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.PauseJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "ResumeJob": grpc.unary_unary_rpc_method_handler(
            servicer.ResumeJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.ResumeJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "RunJob": grpc.unary_unary_rpc_method_handler(
            servicer.RunJob,
            request_deserializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_cloudscheduler__pb2.RunJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_scheduler__v1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.scheduler.v1.CloudScheduler", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/scheduler_v1/proto/job.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.scheduler_v1.proto import (
    target_pb2 as google_dot_cloud_dot_scheduler__v1_dot_proto_dot_target__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/scheduler_v1/proto/job.proto",
    package="google.cloud.scheduler.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\035com.google.cloud.scheduler.v1B\010JobProtoP\001ZBgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1;scheduler"
    ),
    serialized_pb=_b(
        '\n)google/cloud/scheduler_v1/proto/job.proto\x12\x19google.cloud.scheduler.v1\x1a\x1cgoogle/api/annotations.proto\x1a,google/cloud/scheduler_v1/proto/target.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto"\xba\x05\n\x03Job\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12@\n\rpubsub_target\x18\x04 \x01(\x0b\x32\'.google.cloud.scheduler.v1.PubsubTargetH\x00\x12P\n\x16\x61pp_engine_http_target\x18\x05 \x01(\x0b\x32..google.cloud.scheduler.v1.AppEngineHttpTargetH\x00\x12<\n\x0bhttp_target\x18\x06 \x01(\x0b\x32%.google.cloud.scheduler.v1.HttpTargetH\x00\x12\x10\n\x08schedule\x18\x14 \x01(\t\x12\x11\n\ttime_zone\x18\x15 \x01(\t\x12\x34\n\x10user_update_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x05state\x18\n \x01(\x0e\x32$.google.cloud.scheduler.v1.Job.State\x12"\n\x06status\x18\x0b \x01(\x0b\x32\x12.google.rpc.Status\x12\x31\n\rschedule_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11last_attempt_time\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0cretry_config\x18\x13 \x01(\x0b\x32&.google.cloud.scheduler.v1.RetryConfig"X\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x11\n\rUPDATE_FAILED\x10\x04\x42\x08\n\x06target"\xe2\x01\n\x0bRetryConfig\x12\x13\n\x0bretry_count\x18\x01 \x01(\x05\x12\x35\n\x12max_retry_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x14min_backoff_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x14max_backoff_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x15\n\rmax_doublings\x18\x05 \x01(\x05\x42o\n\x1d\x63om.google.cloud.scheduler.v1B\x08JobProtoP\x01ZBgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1;schedulerb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_scheduler__v1_dot_proto_dot_target__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
    ],
)


_JOB_STATE = _descriptor.EnumDescriptor(
    name="State",
    full_name="google.cloud.scheduler.v1.Job.State",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ENABLED", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PAUSED", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DISABLED", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="UPDATE_FAILED", index=4, number=4, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=839,
    serialized_end=927,
)
_sym_db.RegisterEnumDescriptor(_JOB_STATE)


_JOB = _descriptor.Descriptor(
    name="Job",
    full_name="google.cloud.scheduler.v1.Job",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.scheduler.v1.Job.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.scheduler.v1.Job.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="pubsub_target",
            full_name="google.cloud.scheduler.v1.Job.pubsub_target",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="app_engine_http_target",
            full_name="google.cloud.scheduler.v1.Job.app_engine_http_target",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="http_target",
            full_name="google.cloud.scheduler.v1.Job.http_target",
            index=4,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="schedule",
            full_name="google.cloud.scheduler.v1.Job.schedule",
            index=5,
            number=20,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="time_zone",
            full_name="google.cloud.scheduler.v1.Job.time_zone",
            index=6,
            number=21,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_update_time",
            full_name="google.cloud.scheduler.v1.Job.user_update_time",
            index=7,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.scheduler.v1.Job.state",
            index=8,
            number=10,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="google.cloud.scheduler.v1.Job.status",
            index=9,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="schedule_time",
            full_name="google.cloud.scheduler.v1.Job.schedule_time",
            index=10,
            number=17,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="last_attempt_time",
            full_name="google.cloud.scheduler.v1.Job.last_attempt_time",
            index=11,
            number=18,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="retry_config",
            full_name="google.cloud.scheduler.v1.Job.retry_config",
            index=12,
            number=19,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_JOB_STATE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="target",
            full_name="google.cloud.scheduler.v1.Job.target",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=239,
    serialized_end=937,
)


_RETRYCONFIG = _descriptor.Descriptor(
    name="RetryConfig",
    full_name="google.cloud.scheduler.v1.RetryConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="retry_count",
            full_name="google.cloud.scheduler.v1.RetryConfig.retry_count",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max_retry_duration",
            full_name="google.cloud.scheduler.v1.RetryConfig.max_retry_duration",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="min_backoff_duration",
            full_name="google.cloud.scheduler.v1.RetryConfig.min_backoff_duration",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max_backoff_duration",
            full_name="google.cloud.scheduler.v1.RetryConfig.max_backoff_duration",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max_doublings",
            full_name="google.cloud.scheduler.v1.RetryConfig.max_doublings",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=940,
    serialized_end=1166,
)

_JOB.fields_by_name[
    "pubsub_target"
].message_type = (
    google_dot_cloud_dot_scheduler__v1_dot_proto_dot_target__pb2._PUBSUBTARGET
)
_JOB.fields_by_name[
    "app_engine_http_target"
].message_type = (
    google_dot_cloud_dot_scheduler__v1_dot_proto_dot_target__pb2._APPENGINEHTTPTARGET
)
_JOB.fields_by_name[
    "http_target"
].message_type = (
    google_dot_cloud_dot_scheduler__v1_dot_proto_dot_target__pb2._HTTPTARGET
)
_JOB.fields_by_name[
    "user_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name["state"].enum_type = _JOB_STATE
_JOB.fields_by_name["status"].message_type = google_dot_rpc_dot_status__pb2._STATUS
_JOB.fields_by_name[
    "schedule_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name[
    "last_attempt_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name["retry_config"].message_type = _RETRYCONFIG
_JOB_STATE.containing_type = _JOB
_JOB.oneofs_by_name["target"].fields.append(_JOB.fields_by_name["pubsub_target"])
_JOB.fields_by_name["pubsub_target"].containing_oneof = _JOB.oneofs_by_name["target"]
_JOB.oneofs_by_name["target"].fields.append(
    _JOB.fields_by_name["app_engine_http_target"]
)
_JOB.fields_by_name["app_engine_http_target"].containing_oneof = _JOB.oneofs_by_name[
    "target"
]
_JOB.oneofs_by_name["target"].fields.append(_JOB.fields_by_name["http_target"])
_JOB.fields_by_name["http_target"].containing_oneof = _JOB.oneofs_by_name["target"]
_RETRYCONFIG.fields_by_name[
    "max_retry_duration"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYCONFIG.fields_by_name[
    "min_backoff_duration"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYCONFIG.fields_by_name[
    "max_backoff_duration"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name["Job"] = _JOB
DESCRIPTOR.message_types_by_name["RetryConfig"] = _RETRYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType(
    "Job",
    (_message.Message,),
    dict(
        DESCRIPTOR=_JOB,
        __module__="google.cloud.scheduler_v1.proto.job_pb2",
        __doc__="""Configuration for a job. The maximum allowed size for a job is 100KB.
  
  
  Attributes:
      name:
          Optionally caller-specified in [CreateJob][google.cloud.schedu
          ler.v1.CloudScheduler.CreateJob], after which it becomes
          output only.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.  -
          ``PROJECT_ID`` can contain letters ([A-Za-z]), numbers
          ([0-9]),    hyphens (-), colons (:), or periods (.). For more
          information, see    `Identifying    projects
          <https://cloud.google.com/resource-manager/docs/creating-
          managing-projects#identifying_projects>`__ -  ``LOCATION_ID``
          is the canonical ID for the job's location. The list    of
          available locations can be obtained by calling    [ListLocatio
          ns][google.cloud.location.Locations.ListLocations]. For
          more information, see
          https://cloud.google.com/about/locations/. -  ``JOB_ID`` can
          contain only letters ([A-Za-z]), numbers ([0-9]),    hyphens
          (-), or underscores (\_). The maximum length is 500
          characters.
      description:
          Optionally caller-specified in [CreateJob][google.cloud.schedu
          ler.v1.CloudScheduler.CreateJob] or [UpdateJob][google.cloud.s
          cheduler.v1.CloudScheduler.UpdateJob].  A human-readable
          description for the job. This string must not contain more
          than 500 characters.
      target:
          Required.  Delivery settings containing destination and
          parameters.
      pubsub_target:
          Pub/Sub target.
      app_engine_http_target:
          App Engine HTTP target.
      http_target:
          HTTP target.
      schedule:
          Required, except when used with [UpdateJob][google.cloud.sched
          uler.v1.CloudScheduler.UpdateJob].  Describes the schedule on
          which the job will be executed.  The schedule can be either of
          the following types:  -  `Crontab
          <http://en.wikipedia.org/wiki/Cron#Overview>`__ -  English-
          like    `schedule
          <https://cloud.google.com/scheduler/docs/configuring/cron-job-
          schedules>`__  As a general rule, execution ``n + 1`` of a job
          will not begin until execution ``n`` has finished. Cloud
          Scheduler will never allow two simultaneously outstanding
          executions. For example, this implies that if the ``n+1``\ th
          execution is scheduled to run at 16:00 but the ``n``\ th
          execution takes until 16:15, the ``n+1``\ th execution will
          not start until ``16:15``. A scheduled start time will be
          delayed if the previous execution has not ended when its
          scheduled time occurs.  If [retry\_count][google.cloud.schedul
          er.v1.RetryConfig.retry\_count] > 0 and a job attempt fails,
          the job will be tried a total of [retry\_count][google.cloud.s
          cheduler.v1.RetryConfig.retry\_count] times, with exponential
          backoff, until the next scheduled start time.
      time_zone:
          Specifies the time zone to be used in interpreting
          [schedule][google.cloud.scheduler.v1.Job.schedule]. The value
          of this field must be a time zone name from the `tz database
          <http://en.wikipedia.org/wiki/Tz_database>`__.  Note that some
          time zones include a provision for daylight savings time. The
          rules for daylight saving time are determined by the chosen
          tz. For UTC use the string "utc". If a time zone is not
          specified, the default will be in UTC (also known as GMT).
      user_update_time:
          Output only. The creation time of the job.
      state:
          Output only. State of the job.
      status:
          Output only. The response from the target for the last
          attempted execution.
      schedule_time:
          Output only. The next time the job is scheduled. Note that
          this may be a retry of a previously failed attempt or the next
          execution time according to the schedule.
      last_attempt_time:
          Output only. The time the last job attempt started.
      retry_config:
          Settings that determine the retry behavior.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.Job)
    ),
)
_sym_db.RegisterMessage(Job)

RetryConfig = _reflection.GeneratedProtocolMessageType(
    "RetryConfig",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RETRYCONFIG,
        __module__="google.cloud.scheduler_v1.proto.job_pb2",
        __doc__="""Settings that determine the retry behavior.
  
  By default, if a job does not complete successfully (meaning that an
  acknowledgement is not received from the handler, then it will be
  retried with exponential backoff according to the settings in
  [RetryConfig][google.cloud.scheduler.v1.RetryConfig].
  
  
  Attributes:
      retry_count:
          The number of attempts that the system will make to run a job
          using the exponential backoff procedure described by [max\_dou
          blings][google.cloud.scheduler.v1.RetryConfig.max\_doublings].
          The default value of retry\_count is zero.  If retry\_count is
          zero, a job attempt will *not* be retried if it fails. Instead
          the Cloud Scheduler system will wait for the next scheduled
          execution time.  If retry\_count is set to a non-zero number
          then Cloud Scheduler will retry failed attempts, using
          exponential backoff, retry\_count times, or until the next
          scheduled execution time, whichever comes first.  Values
          greater than 5 and negative values are not allowed.
      max_retry_duration:
          The time limit for retrying a failed job, measured from time
          when an execution was first attempted. If specified with [retr
          y\_count][google.cloud.scheduler.v1.RetryConfig.retry\_count],
          the job will be retried until both limits are reached.  The
          default value for max\_retry\_duration is zero, which means
          retry duration is unlimited.
      min_backoff_duration:
          The minimum amount of time to wait before retrying a job after
          it fails.  The default value of this field is 5 seconds.
      max_backoff_duration:
          The maximum amount of time to wait before retrying a job after
          it fails.  The default value of this field is 1 hour.
      max_doublings:
          The time between retries will double ``max_doublings`` times.
          A job's retry interval starts at [min\_backoff\_duration][goog
          le.cloud.scheduler.v1.RetryConfig.min\_backoff\_duration],
          then doubles ``max_doublings`` times, then increases linearly,
          and finally retries retries at intervals of [max\_backoff\_dur
          ation][google.cloud.scheduler.v1.RetryConfig.max\_backoff\_dur
          ation] up to [retry\_count][google.cloud.scheduler.v1.RetryCon
          fig.retry\_count] times.  For example, if [min\_backoff\_durat
          ion][google.cloud.scheduler.v1.RetryConfig.min\_backoff\_durat
          ion] is 10s, [max\_backoff\_duration][google.cloud.scheduler.v
          1.RetryConfig.max\_backoff\_duration] is 300s, and
          ``max_doublings`` is 3, then the a job will first be retried
          in 10s. The retry interval will double three times, and then
          increase linearly by 2^3 \* 10s. Finally, the job will retry
          at intervals of [max\_backoff\_duration][google.cloud.schedule
          r.v1.RetryConfig.max\_backoff\_duration] until the job has
          been attempted [retry\_count][google.cloud.scheduler.v1.RetryC
          onfig.retry\_count] times. Thus, the requests will retry at
          10s, 20s, 40s, 80s, 160s, 240s, 300s, 300s, ....  The default
          value of this field is 5.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1.RetryConfig)
    ),
)
_sym_db.RegisterMessage(RetryConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
